pub enum Status {
CheckedOut,
Processing,
Error,
Finished,
Examination,
}Variants
CheckedOut
Only checked out for that commit
Processing
Currently running in process_working_directory
Error
Project benchmarking gave error for that commit (means working dir is set aside)
Finished
Project benchmarking ran through for that commit
Examination
Marked for examination, probably after an Error happened and it was decided to keep the directory around
Implementations