pub struct WorkingDirectoryAutoCleanOpts {
pub min_age_days: u16,
pub min_num_runs: usize,
pub wait_until_commit_done: bool,
}Fields
min_age_days: u16The minimum age a working directory should reach before possibly being deleted, in days (recommended: 3)
min_num_runs: usizeThe minimum number of jobs that should be run in a working directory before that is possibly being deleted (recommended: 80).
wait_until_commit_done: boolIf true, directories are not deleted when any job for the same
commit id is in the queue. (Directories are deleted when they
reach both the min_age_days and min_num_runs numbers, and
this is false, or the current job just ended and no others for
the commit id exist.)