pub struct WorkingDirectoryPath(/* private fields */);Expand description
A path to a working directory. Has methods that only need a path, nothing else.
Implementations
Sourceimpl WorkingDirectoryPath
impl WorkingDirectoryPath
Sourcepub fn standard_log_path(
&self,
timestamp: &DateTimeWithOffset,
) -> Result<PathBuf>
pub fn standard_log_path( &self, timestamp: &DateTimeWithOffset, ) -> Result<PathBuf>
The path to which the stdout and stderr of the target process is logged, including a header with the serialized key data (before it is moved/compressed to the output directory when the run was successful)
Sourcepub fn parent_path_and_id(&self) -> Result<(&Path, &str)>
pub fn parent_path_and_id(&self) -> Result<(&Path, &str)>
Originally thought id is a pool matter only, but now need it
to filter for standard_log paths. Leaving id as string,
though.)
Sourcepub fn standard_log_paths(&self) -> Result<Vec<(PathBuf, String)>>
pub fn standard_log_paths(&self) -> Result<Vec<(PathBuf, String)>>
All stdout log files that were written for this working directory: path including file name, just the timestamp. Sorted by timestamp, newest last.
pub fn last_standard_log_path(&self) -> Result<Option<(PathBuf, String)>>
pub fn noncached_commit(&self) -> Result<GitHash>